# MUNITY API

Set of application used by *Django Rest Framework* to bootstrap brand new SaaS in an **awesome** way!

**Munity** limit ***technical debt***, so you can focus on your buisness.

[Munity github project](https://github.com/munityapps/munity)